@@ -202,7 +202,6 @@ def JSON_to_checks(check_results_json):
     for job in check_results_json:
         all_check_results[job] = {}
         for check, json_data in check_results_json[job].items():
-
             checks_data[check] = json_data["input"]
 
             all_check_results[job][check] = CheckResult(
@@ -383,6 +382,15 @@ def _add_check_results(check_data, *results):
                 res.passed for res in results
             )
 
+        elif added_result.check_type == "duplicate_inputs":
+            added_result.passed = all([res.passed for res in results])
+
+        elif added_result.check_type == "job_name_matches_polarity":
+            added_result.passed = all([res.passed for res in results])
+
+        elif added_result.check_type == "both_polarities_used":
+            added_result.passed = all([res.passed for res in results])
+
     return added_result
 
 
@@ -422,7 +430,8 @@ def combine_checks(checks_info_tuple_list):
             else:
                 if c_data != checks_data[c_name]:
                     warnings.warn(
-                        f"Found check with duplicate name ({c_name}) but different configuration - cannot be combined"
+                        f"Found check with duplicate name ({c_name}) but different configuration - cannot be combined",
+                        stacklevel=2,
                     )
 
     # Create a dict containing indices of datasets to include when combining a check for each job
@@ -430,7 +439,6 @@ def combine_checks(checks_info_tuple_list):
     for i, tup in enumerate(checks_info_tuple_list):
         data, results = tup
         for job_name, job_check_results in results.items():
-
             # Add job if not already present
             if job_name not in checks_datasets:
                 checks_datasets[job_name] = {}
@@ -448,7 +456,8 @@ def combine_checks(checks_info_tuple_list):
                 if not job_check_results[check_name].can_combine:
                     warnings.warn(
                         f"The result for {job_name} cannot be included in the {check_name} "
-                        "combination as the can_combine flag is False."
+                        "combination as the can_combine flag is False.",
+                        stacklevel=2,
                     )
                     continue
                 checks_datasets[job_name][check_name].append(i)
