@@ -37,3 +37,13 @@ known_data_types = ["Upgrade", "2011", "2012", "2015", "2016", "2017", "2018"]
 known_input_types = ["DST", "MDST"]
 
 allowed_priorities = ["1a", "1b", "2a", "2b"]
+
+simple_validations = [
+    "duplicate_inputs",
+    "job_name_matches_polarity",
+    "both_polarities_used",
+]
+validation_types = [
+    *simple_validations,
+]
+validation_modes = ["Strict", "Lenient", "None"]
