@@ -10,7 +10,7 @@
 ###############################################################################
 
 import re
-from collections import OrderedDict, defaultdict
+from collections import OrderedDict
 from os.path import isfile, join, relpath
 
 import jinja2
@@ -23,7 +23,7 @@ from strictyaml import Regex, Seq, Str, load
 from LbAPCommon import config
 from LbAPCommon.linting.bk_paths import validate_bk_query
 
-RE_APPLICATION = r"^([A-Za-z]+/)+v\d+r\d+(p\d+)?"
+RE_APPLICATION = r"^([A-Za-z]+/)+v\d+r\d+(p\d+)?(\@[a-z0-9_\-\+]+)?"
 RE_JOB_NAME = r"^[a-zA-Z0-9][a-zA-Z0-9_\-]+$"
 RE_OUTPUT_FILE_TYPE = r"^([A-Za-z][A-Za-z0-9_]+\.)+((ROOT|root)|.?(DST|dst))$"
 RE_OPTIONS_FN = r"^\$?[a-zA-Z0-9/\.\-\+\=_]+$"
@@ -36,6 +36,8 @@ RE_CONDDB_TAG = r"^.{1,50}$"
 RE_COMMENT = r"(.{1,5000})"
 DQ_FLAGS_SCHEMA = Seq(Enum(["BAD", "OK", "EXPRESS_OK", "UNCHECKED"]))
 
+RE_INCLUSIVE_RUN_RANGE = r"\d+:\d+"
+
 LEGACY_OPTIONS = {
     Optional("command"): Seq(Str()),
     "files": Seq(Regex(RE_OPTIONS_FN)),
@@ -66,7 +68,9 @@ BASE_JOB_SCHEMA = {
     Optional("dddb_tag"): Regex(RE_DDDB_TAG),
     Optional("conddb_tag"): Regex(RE_CONDDB_TAG),
     Optional("checks"): Seq(Str()),  # TODO: replace this with a regex
-    Optional("extra_checks"): Seq(Str()),  # TODO: replace this with a regex
+    Optional("extra_checks"): Seq(
+        Str()
+    ),  # TODO: replace this with a regex or with something like the line below
     # Production submission metadata
     Optional("comment"): Regex(RE_COMMENT),
     "priority": Enum(config.allowed_priorities),
@@ -74,7 +78,12 @@ BASE_JOB_SCHEMA = {
 }
 INPUT_SCHEMAS = {
     "bk_query": Map(
-        {"bk_query": Str(), Opt("n_test_lfns"): Int(), Opt("dq_flags"): DQ_FLAGS_SCHEMA}
+        {
+            "bk_query": Str(),
+            Opt("n_test_lfns"): Int(),
+            Opt("dq_flags"): DQ_FLAGS_SCHEMA,
+            Opt("runs"): Seq(Int() | Regex(RE_INCLUSIVE_RUN_RANGE)),
+        }
     ),
     "job_name": Map({"job_name": Str(), Opt("filetype"): Regex(RE_OUTPUT_FILE_TYPE)}),
     "transform_ids": Map(
@@ -83,6 +92,7 @@ INPUT_SCHEMAS = {
             "filetype": Regex(RE_OUTPUT_FILE_TYPE),
             Opt("n_test_lfns"): Int(),
             Opt("dq_flags"): DQ_FLAGS_SCHEMA,
+            Opt("runs"): Seq(Int() | Regex(RE_INCLUSIVE_RUN_RANGE)),
         }
     ),
 }
@@ -95,6 +105,7 @@ DEFAULT_JOB_VALUES = {
 
 CHECK_TYPE_SCHEMAS = {
     "range": {
+        Optional("mode"): Enum(config.validation_modes),
         "expression": Str(),  # TODO: replace this with a regex
         "limits": Map({"min": Float(), "max": Float()}),
         Optional("n_bins"): Int(),
@@ -106,6 +117,7 @@ CHECK_TYPE_SCHEMAS = {
         Optional("std_tolerance"): Float(),
     },
     "range_nd": {
+        Optional("mode"): Enum(config.validation_modes),
         "expressions": Map(
             {  # TODO: replace Str() with a regex
                 "x": Str(),
@@ -138,13 +150,16 @@ CHECK_TYPE_SCHEMAS = {
         ),
     },
     "num_entries": {
+        Optional("mode"): Enum(config.validation_modes),
         "count": Int(),
     },
     "num_entries_per_invpb": {
+        Optional("mode"): Enum(config.validation_modes),
         "count_per_invpb": Float(),
         Optional("lumi_pattern"): Str(),
     },
     "range_bkg_subtracted": {
+        Optional("mode"): Enum(config.validation_modes),
         "expression": Str(),
         "limits": Map({"min": Float(), "max": Float()}),
         "expr_for_subtraction": Str(),
@@ -157,9 +172,15 @@ CHECK_TYPE_SCHEMAS = {
         | Seq(Map({"min": Float(), "max": Float()})),
     },
     "branches_exist": {
+        Optional("mode"): Enum(config.validation_modes),
         "branches": Seq(Str()),
     },
 }
+BASIC_VALIDATION_SCHEMAS = {
+    validation_type: {"mode": Enum(config.validation_modes)}
+    for validation_type in config.validation_types
+}
+CHECK_TYPE_SCHEMAS = {**CHECK_TYPE_SCHEMAS, **BASIC_VALIDATION_SCHEMAS}
 BASE_CHECK_SCHEMA = {
     "type": Enum(list(CHECK_TYPE_SCHEMAS)),
     Optional("tree_pattern"): Str(),
@@ -168,6 +189,7 @@ BASE_CHECK_DEFAULT_VALUES = {
     "tree_pattern": r"(.*/DecayTree)|(.*/MCDecayTree)",
 }
 CHECK_TYPE_DEFAULT_VALUES = {
+    "mode": "Strict",
     "num_entries": {},
     "range": {
         "n_bins": 50,
@@ -187,6 +209,13 @@ CHECK_TYPE_DEFAULT_VALUES = {
     },
     "branches_exist": {},
 }
+BASIC_VALIDATION_DEFAULT_VALUES = {
+    validation_type: {"mode": "Strict"} for validation_type in config.validation_types
+}
+CHECK_TYPE_DEFAULT_VALUES = {
+    **CHECK_TYPE_DEFAULT_VALUES,
+    **BASIC_VALIDATION_DEFAULT_VALUES,
+}
 
 
 def _ordered_dict_to_dict(a):
@@ -244,11 +273,11 @@ def _validate_proc_pass_map(job_names, proc_pass_map):
             proc_pass = proc_pass_map[job_name]
             step_jobs_list = "  - " + "\n  - ".join(job_names)
             raise ValueError(
-                f"The expected processing path length for the job '{job_name}' is too long.\n"
+                f"The expected processing path length for the job {job_name!r} is too long.\n"
                 "DIRAC requires this to be less than 100 characters.\n\n"
-                f"'Step' jobs:\n{step_jobs_list}\n"
-                f"Job name: {job_name}\n"
-                f"Processing pass for this step: {proc_pass}\n"
+                f"'Step' jobs:\n{step_jobs_list!r}\n"
+                f"Job name: {job_name!r}\n"
+                f"Processing pass for this step: {proc_pass!r}\n"
                 f"Processing path for this step ({len(pro_path)} chars): {pro_path}\n\n"
                 "To recover from this issue, consider:"
                 "  - Removing redundant information from your job name.\n"
@@ -525,42 +554,10 @@ def _check_name_magnet_polarity(bk_query, job_name):
     return []
 
 
-def _check_job_chain_name_polarity(job_name: str, input_job_name: str) -> list:
-    mags = ["mag", "m"]
-    down = ["down", "d"]
-    up = ["up", "u"]
-    for i, pattern in enumerate(
-        [
-            r"([^a-z0-9]|\b)mag(up|down)([^a-z0-9]|\b)",
-            r"([^a-z0-9]|\b)m(u|d)([^a-z0-9]|\b)",
-        ]
-    ):
-        matches = [
-            re.search(pattern, name, re.IGNORECASE)
-            for name in [job_name, input_job_name]
-        ]
-        if matches[1]:
-            groups = [group for group in matches[1].groups() if group != "_"]
-            good_pol = groups[0].lower()
-            bad_pol = {down[i]: up[i], up[i]: down[i]}[good_pol]
-            if f"{mags[i]}{bad_pol}" in job_name.lower():
-                raise ValueError(
-                    f"Found '{mags[i]}{bad_pol}' in job name {job_name!r} with"
-                    f" '{mags[i]}{good_pol}' input ({input_job_name!r}). "
-                    "Has the wrong magnet polarity been used?"
-                )
-            break
-    else:
-        return [
-            f"Failed to find magnet polarity in {input_job_name}, "
-            "cannot determine if polarities are matched throughout the job chain"
-        ]
-
-    return []
-
-
 def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
-    """Validate YAML configuration.
+    """Validate YAML configuration for anything that would definitely break a job or the production.
+
+    Other validations that aren't essential for at least testing a job are done via the checks framework.
 
     Args:
         jobs_data (dict): Parsed job configuration.
@@ -570,14 +567,7 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
 
     Raises:
         ValueError: Raised if there are showstopper issues in the parsed job configuration.
-
-    Returns:
-        list[str]: warnings (not showstoppers) raised during validation of the configuration.
     """
-    bk_query_to_job = defaultdict(set)
-
-    warnings = []
-
     # Ensure all values that can be either a list or a string are lists of strings
     for job_name, job_data in jobs_data.items():
         try:
@@ -585,22 +575,13 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
         except Exception as e:
             raise ValueError(f"Failed to validate {job_name!r} with error {e!r}") from e
 
-        if "bk_query" in job_data["input"]:
-            if job_data["input"]["bk_query"].lower() in bk_query_to_job:
-                warnings.append(
-                    f'Duplicate bk_query found (this is a case insensitive check): {job_data["input"]["bk_query"].lower()}'
-                )
-            bk_query_to_job[job_data["input"]["bk_query"].lower()].add(job_name.lower())
-
-        elif "job_name" in job_data["input"]:
-            # Ensure that the job name and output filetype are unambiguously defined
+    # Ensure job name inputs are unambiguous
+    for job_name, job_data in jobs_data.items():
+        if "job_name" in job_data["input"]:
             if job_data["input"]["job_name"] not in jobs_data:
                 raise ValueError(
                     f"Unrecognised job name in input: {job_data['input']['job_name']}"
                 )
-            warnings.extend(
-                _check_job_chain_name_polarity(job_name, job_data["input"]["job_name"])
-            )
             input_job_data = jobs_data[job_data["input"]["job_name"]]
             input_filetype = job_data["input"].get("filetype", "").upper()
             if len(input_job_data["output"]) == 1:
@@ -620,58 +601,12 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
                     f"expected one of: {input_job_data['output']}"
                 )
 
-    for query, job_set in bk_query_to_job.items():
-        for job_name in job_set:
-            warnings.extend(_check_name_magnet_polarity(query, job_name))
-
-    polarity_len_swap = {"magdown": 5, "magup": 7}
-    polarity_swap = {"magdown": "magup", "magup": "magdown"}
-
-    # check that both polarities are always used for a given bk_query
-    for query in bk_query_to_job:
-        index = None
-        query_polarity = None
-        both_polarities = False
-        for polarity in {"magdown", "magup"}:
-            if polarity in query:
-                index = query.find(polarity)
-                query_polarity = polarity
-        if query_polarity:
-            for compare_query in bk_query_to_job:
-                if compare_query != query:
-                    if polarity_swap[query_polarity] in compare_query:
-                        if (
-                            compare_query[:index]
-                            + query_polarity
-                            + compare_query[
-                                (index + polarity_len_swap[query_polarity]) :
-                            ]
-                            == query
-                        ):
-                            both_polarities = True
-                            if len(bk_query_to_job[query]) != len(
-                                bk_query_to_job[compare_query]
-                            ):
-                                warnings.append(
-                                    f"The number of jobs requesting {query} does not"
-                                    " match the number of jobs requesting its opposite"
-                                    f" polarity counterpart {compare_query}."
-                                )
-            if not both_polarities:
-                warnings.append(
-                    f"{query} has been requested as input for {len(bk_query_to_job[query])} job(s)"
-                    " but its opposite polarity counterpart has not been requested for any jobs."
-                    " Are you sure you do not want the other polarity?"
-                )
-
     # Validate checks
     try:
         _validate_checks_data(checks_data, jobs_data)
     except Exception as e:
         raise ValueError(f"Failed to validate checks with error {e!r}") from e
 
-    return warnings
-
 
 def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
     # Normalise list/str fields to always be lists
@@ -721,8 +656,8 @@ def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
     # Validate the completion percentage
     if not (10 <= job_data["completion_percentage"] <= 100):
         raise ValueError(
-            f"Validation failed for job '{job_name}', completion_percentage "
-            f"was set to '{job_data['completion_percentage']}', allowed "
+            f"Validation failed for job {job_name!r}, completion_percentage "
+            f"was set to {job_data['completion_percentage']!r}, allowed "
             "values are in the interval [10, 100]."
         )
 
@@ -765,5 +700,5 @@ def _validate_checks_data(checks_data, jobs_data):
             for pair in req_pair_tuples + [tup[::-1] for tup in req_pair_tuples]:
                 if (cdata.get(pair[0]) is not None) and (cdata.get(pair[1])) is None:
                     raise ValueError(
-                        f"When using '{pair[0]}', must also specify '{pair[1]}'"
+                        f"When using {pair[0]!r}, must also specify {pair[1]!r}"
                     )
