@@ -16,7 +16,7 @@ import LbAPCommon
 from LbAPCommon import checks
 from LbAPCommon.checks_utils import checks_to_JSON
 
-pytest.importorskip("XRootD")
+pytest.importorskip("XRootD")  # tests here will not run on CI
 
 
 def test_num_entries_parsing_to_JSON():
@@ -48,6 +48,8 @@ def test_num_entries_parsing_to_JSON():
     check_name = list(checks_data.keys())[0]
 
     result = checks.run_job_checks(
+        jobs_data,
+        job_name,
         [check_name],
         checks_data,
         [
@@ -130,6 +132,8 @@ def test_range_parsing_to_JSON():
     check_name = list(checks_data.keys())[0]
 
     result = checks.run_job_checks(
+        jobs_data,
+        job_name,
         [check_name],
         checks_data,
         [
@@ -355,6 +359,8 @@ def test_range_2d_parsing_to_JSON():
     check_name = list(checks_data.keys())[0]
 
     result = checks.run_job_checks(
+        jobs_data,
+        job_name,
         [check_name],
         checks_data,
         [
@@ -479,7 +485,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -508,7 +514,7 @@ def test_range_2d_parsing_to_JSON():
                   2.0,
                   1.0,
                   1.0,
-                  2.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -566,7 +572,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -856,7 +862,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -885,7 +891,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -1179,20 +1185,6 @@ def test_range_2d_parsing_to_JSON():
                 ],
                 [
                   0.0,
-                  1012.0,
-                  222.0,
-                  67.0,
-                  24.0,
-                  16.0,
-                  5.0,
-                  7.0,
-                  5.0,
-                  2.0,
-                  0.0,
-                  0.0,
-                  0.0,
-                  2.0,
-                  1.0,
                   0.0,
                   0.0,
                   0.0,
@@ -1204,7 +1196,21 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0
                 ]
               ],
               "sumw2": [
@@ -1264,7 +1270,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -1293,7 +1299,7 @@ def test_range_2d_parsing_to_JSON():
                   2.0,
                   1.0,
                   1.0,
-                  2.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -1351,7 +1357,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -1641,7 +1647,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -1670,7 +1676,7 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0
                 ],
                 [
                   0.0,
@@ -1964,20 +1970,6 @@ def test_range_2d_parsing_to_JSON():
                 ],
                 [
                   0.0,
-                  1012.0,
-                  222.0,
-                  67.0,
-                  24.0,
-                  16.0,
-                  5.0,
-                  7.0,
-                  5.0,
-                  2.0,
-                  0.0,
-                  0.0,
-                  0.0,
-                  2.0,
-                  1.0,
                   0.0,
                   0.0,
                   0.0,
@@ -1989,12 +1981,26 @@ def test_range_2d_parsing_to_JSON():
                   0.0,
                   0.0,
                   0.0,
-                  1.0
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0,
+                  0.0
                 ]
               ]
             }
           ],
-          "num_entries": 5135823
+          "num_entries": 5134453
         }
       }
     }
