@@ -1129,316 +1129,3 @@ def test_filetype_validation():
 
     assert _normalise_filetype("PROD", "JOB", "XICPS_MC.ROOT") == "XICPS_MC.ROOT"
     assert _normalise_filetype("PROD", "JOB", "xicps_mc.root") == "XICPS_MC.ROOT"
-
-
-def test_wrong_polarity():
-    rendered_yaml = dedent(
-        """\
-    job_MagDown:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_MagUp:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2017/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    with pytest.raises(ValueError):
-        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-
-
-def test_wrong_polarity_acronym():
-    rendered_yaml = dedent(
-        """\
-    job_MD:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_MU:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2017/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    with pytest.raises(ValueError):
-        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-
-
-def test_tuple_in_job_name():
-    rendered_yaml = dedent(
-        """\
-    job_MagDown_tuple:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_MagUp_tuple:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-    assert warnings == []
-
-
-def test_polarity_acronym():
-    rendered_yaml = dedent(
-        """\
-    job_MagDown_2018:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_MagUp_2018:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_MD_2017:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2017/Beam6500GeV-2017-MagDown/Sim09g/Trig0x62661709/Reco17/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_MU_2017:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2017/Beam6500GeV-2017-MagUp/Sim09g/Trig0x62661709/Reco17/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-    assert warnings == []
-
-
-def test_missing_polarity():
-    rendered_yaml = dedent(
-        """\
-    job_MagDown:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-    assert (
-        "/mc/2018/beam6500gev-2018-magdown/sim09g/trig0x617d18a4/reco18/24142001/allstreams.dst"
-        " has been requested as input for 1 job(s)"
-        " but its opposite polarity counterpart has not been requested for any jobs."
-        " Are you sure you do not want the other polarity?" in warnings
-    )
-
-
-def test_duplicate_bk_query():
-    rendered_yaml = dedent(
-        """\
-    job_1:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_2:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/b.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-    assert (
-        "Duplicate bk_query found (this is a case insensitive check): "
-        "/mc/2018/beam6500gev-2018-magdown/sim09g/trig0x617d18a4/reco18/24142001/allstreams.dst"
-        in warnings
-    )
-
-
-def test_good_job_chain_polarity():
-    rendered_yaml = dedent(
-        """\
-    job_1_MagDown:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.DST
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_1_MagUp:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.DST
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_2_MagDown:
-        application: DaVinci/v45r3
-        input:
-            job_name: job_1_MagDown
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/b.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-    assert warnings == []
-
-
-def test_bad_job_chain_polarity():
-    rendered_yaml = dedent(
-        """\
-    job_1_MagDown:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.DST
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_1_MagUp:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.DST
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_2_MagDown:
-        application: DaVinci/v45r3
-        input:
-            job_name: job_1_MagUp
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/b.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    with pytest.raises(ValueError):
-        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-
-
-def test_missing_job_chain_polarity():
-    rendered_yaml = dedent(
-        """\
-    job_1_x:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.DST
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_1_y:
-        application: DaVinci/v45r3
-        input:
-            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
-        output: FILETYPE.DST
-        options:
-            - $VAR/a.py
-        wg: Charm
-        inform: a.b@c.d
-
-    job_2:
-        application: DaVinci/v45r3
-        input:
-            job_name: job_1_x
-        output: FILETYPE.ROOT
-        options:
-            - $VAR/b.py
-        wg: Charm
-        inform: a.b@c.d
-    """
-    )
-    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
-    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
-    assert (
-        "Failed to find magnet polarity in job_1_x, cannot determine if polarities are matched throughout the job chain"
-        in warnings
-    )
